# Generated by Django 2.2.12 on 2020-04-29 22:29

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('djcall', '0002_caller_signal_number'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='call',
            options={'verbose_name': 'Call'},
        ),
        migrations.AlterModelOptions(
            name='caller',
            options={'verbose_name': 'Caller'},
        ),
        migrations.AlterField(
            model_name='call',
            name='status',
            field=models.IntegerField(choices=[(0, 'Created'), (1, 'Spooled'), (2, 'Started'), (3, 'Success'), (5, 'Failure'), (6, 'Unspoolable'), (7, 'Canceled')], db_index=True, default=0, editable=False),
        ),
        migrations.AlterField(
            model_name='caller',
            name='status',
            field=models.IntegerField(choices=[(0, 'Created'), (1, 'Spooled'), (2, 'Started'), (3, 'Success'), (4, 'Retrying'), (5, 'Failure'), (6, 'Unspoolable'), (7, 'Canceled')], db_index=True, default=0, editable=False),
        ),
    ]
